@@ -8,7 +8,7 @@ use std::ops::{Add, AddAssign, Div, Mul, Sub, SubAssign};
 use arrow::array::PrimitiveArray;
 use arrow::bitmap::{Bitmap, MutableBitmap};
 use arrow::types::NativeType;
-use num::{Bounded, Float, NumCast, One, ToPrimitive, Zero};
+use num_traits::{Bounded, Float, NumCast, One, ToPrimitive, Zero};
 use window::*;
 
 use crate::data_types::IsFloat;
@@ -22,6 +22,7 @@ type WindowSize = usize;
 type Len = usize;
 
 #[inline]
+/// NaN will be smaller than every valid value
 pub fn compare_fn_nan_min<T>(a: &T, b: &T) -> Ordering
 where
     T: PartialOrd + IsFloat,
@@ -42,6 +43,7 @@ where
 }
 
 #[inline]
+/// NaN will be larger than every valid value
 pub fn compare_fn_nan_max<T>(a: &T, b: &T) -> Ordering
 where
     T: PartialOrd + IsFloat,
