@@ -187,25 +187,15 @@ macro_rules! impl_dyn_series {
             }
 
             fn append(&mut self, other: &Series) -> PolarsResult<()> {
-                if self.0.dtype() == other.dtype() {
-                    self.0.append(other.as_ref().as_ref());
-                    Ok(())
-                } else {
-                    Err(PolarsError::SchemaMisMatch(
-                        "cannot append Series; data types don't match".into(),
-                    ))
-                }
+                polars_ensure!(self.0.dtype() == other.dtype(), append);
+                self.0.append(other.as_ref().as_ref());
+                Ok(())
             }
 
             fn extend(&mut self, other: &Series) -> PolarsResult<()> {
-                if self.0.dtype() == other.dtype() {
-                    self.0.extend(other.as_ref().as_ref());
-                    Ok(())
-                } else {
-                    Err(PolarsError::SchemaMisMatch(
-                        "cannot extend Series; data types don't match".into(),
-                    ))
-                }
+                polars_ensure!(self.0.dtype() == other.dtype(), extend);
+                self.0.extend(other.as_ref().as_ref());
+                Ok(())
             }
 
             fn filter(&self, filter: &BooleanChunked) -> PolarsResult<Series> {
