@@ -126,22 +126,13 @@ impl SeriesTrait for NullChunked {
     }
 
     fn get(&self, index: usize) -> PolarsResult<AnyValue> {
-        if index < self.len() {
-            Ok(AnyValue::Null)
-        } else {
-            Err(PolarsError::ComputeError(
-                format!(
-                    "index {index} is out of bounds on series of length {}",
-                    self.len()
-                )
-                .into(),
-            ))
-        }
+        polars_ensure!(index < self.len(), oob = index, self.len());
+        Ok(AnyValue::Null)
     }
 
     fn slice(&self, offset: i64, length: usize) -> Series {
-        let (offset, length) = slice_offsets(offset, length, self.len());
-        NullChunked::new(self.name.clone(), length - offset).into_series()
+        let (_, length) = slice_offsets(offset, length, self.len());
+        NullChunked::new(self.name.clone(), length).into_series()
     }
 
     fn is_null(&self) -> BooleanChunked {
