@@ -1,24 +1,17 @@
-#[cfg(feature = "test")]
 mod aggregations;
-#[cfg(feature = "test")]
 mod arity;
-#[cfg(all(feature = "test", feature = "strings", feature = "cse"))]
+#[cfg(all(feature = "strings", feature = "cse"))]
 mod cse;
 #[cfg(feature = "parquet")]
 mod io;
-#[cfg(feature = "test")]
 mod logical;
-#[cfg(feature = "test")]
 mod optimization_checks;
-#[cfg(feature = "test")]
 mod predicate_queries;
-#[cfg(feature = "test")]
 mod projection_queries;
-#[cfg(feature = "test")]
 mod queries;
 #[cfg(feature = "streaming")]
 mod streaming;
-#[cfg(feature = "strings")]
+#[cfg(all(feature = "strings", feature = "cse"))]
 mod tpch;
 
 fn get_arenas() -> (Arena<AExpr>, Arena<ALogicalPlan>) {
@@ -158,3 +151,29 @@ pub(crate) fn get_df() -> DataFrame {
         .unwrap();
     df
 }
+
+#[test]
+fn test_foo() -> PolarsResult<()> {
+    let dfa: DataFrame = df![
+        "a" => [1, 2, 2],
+        "b" => ["bleft", "bleft", "bleft"]
+    ]?;
+    let dfb: DataFrame = df![
+        "a" => ["ar", "ar", "ar"],
+        "b" => [1, 2, 2]
+    ]?;
+
+    let out = dfa
+        .lazy()
+        .join(
+            dfb.lazy(),
+            [col("a")],
+            [col("b")],
+            JoinType::AsOf(Default::default()),
+        )
+        .select([col("a"), col("b")])
+        .collect()?;
+
+    dbg!(out);
+    Ok(())
+}
