@@ -2,7 +2,7 @@ use std::any::Any;
 use std::hash::{Hash, Hasher};
 
 use hashbrown::hash_map::RawEntryMut;
-use num::NumCast;
+use num_traits::NumCast;
 use polars_core::export::ahash::RandomState;
 use polars_core::frame::row::AnyValueBuffer;
 use polars_core::prelude::*;
@@ -309,7 +309,7 @@ impl Sink for GenericGroupbySink {
         Ok(SinkResult::CanHaveMoreInput)
     }
 
-    fn combine(&mut self, mut other: Box<dyn Sink>) {
+    fn combine(&mut self, other: &mut dyn Sink) {
         // don't parallel this as this is already done in parallel.
 
         let other = other.as_any().downcast_ref::<Self>().unwrap();
@@ -422,7 +422,7 @@ impl Sink for GenericGroupbySink {
             )));
         }
         let mut df = accumulate_dataframes_vertical_unchecked(dfs);
-        DataFrame::new(std::mem::take(df.get_columns_mut())).map(FinalizedSink::Finished)
+        unsafe { DataFrame::new(std::mem::take(df.get_columns_mut())).map(FinalizedSink::Finished) }
     }
 
     fn as_any(&mut self) -> &mut dyn Any {
