@@ -3,6 +3,7 @@ mod csv;
 mod frame;
 #[cfg(feature = "parquet")]
 mod parquet;
+mod reproject;
 mod union;
 
 #[cfg(feature = "csv-file")]
@@ -10,6 +11,7 @@ pub(crate) use csv::CsvSource;
 pub(crate) use frame::*;
 #[cfg(feature = "parquet")]
 pub(crate) use parquet::*;
+pub(crate) use reproject::*;
 pub(crate) use union::*;
 
 use super::*;
