@@ -223,33 +223,6 @@ impl PredicatePushDown {
                 Ok(lp)
             }
 
-            Melt {
-                input,
-                args,
-                schema,
-            } => {
-                let variable_name = args.variable_name.as_deref().unwrap_or("variable");
-                let value_name = args.value_name.as_deref().unwrap_or("value");
-
-                // predicates that will be done at this level
-                let condition = |name: Arc<str>| {
-                    let name = &*name;
-                    name == variable_name
-                        || name == value_name
-                        || args.value_vars.iter().any(|s| s.as_str() == name)
-                };
-                let local_predicates =
-                    transfer_to_local_by_name(expr_arena, &mut acc_predicates, condition);
-
-                self.pushdown_and_assign(input, acc_predicates, lp_arena, expr_arena)?;
-
-                let lp = ALogicalPlan::Melt {
-                    input,
-                    args,
-                    schema,
-                };
-                Ok(self.optional_apply_predicate(lp, local_predicates, lp_arena, expr_arena))
-            }
             LocalProjection { expr, input, .. } => {
                 self.pushdown_and_assign(input, acc_predicates, lp_arena, expr_arena)?;
 
@@ -540,6 +513,28 @@ impl PredicatePushDown {
                             let lp = self.pushdown_and_continue(lp, acc_predicates, lp_arena, expr_arena, false)?;
                             Ok(self.optional_apply_predicate(lp, local_predicates, lp_arena, expr_arena))
 
+                        }
+                        FunctionNode::Melt {
+                            args,
+                            ..
+                        } => {
+
+                            let variable_name = args.variable_name.as_deref().unwrap_or("variable");
+                            let value_name = args.value_name.as_deref().unwrap_or("value");
+
+                            // predicates that will be done at this level
+                            let condition = |name: Arc<str>| {
+                                let name = &*name;
+                                name == variable_name
+                                    || name == value_name
+                                    || args.value_vars.iter().any(|s| s.as_str() == name)
+                            };
+                            let local_predicates =
+                                transfer_to_local_by_name(expr_arena, &mut acc_predicates, condition);
+
+                            let lp = self.pushdown_and_continue(lp, acc_predicates, lp_arena, expr_arena, false)?;
+                            Ok(self.optional_apply_predicate(lp, local_predicates, lp_arena, expr_arena))
+
                         }
                         _ => {
                             self.pushdown_and_continue(lp, acc_predicates, lp_arena, expr_arena, false)
@@ -588,6 +583,13 @@ impl PredicatePushDown {
                     let predicate = predicate_at_scan(acc_predicates, predicate, expr_arena);
 
                     if let Some(predicate) = predicate {
+                        // simplify expressions before we translate them to pyarrow
+                        let lp = PythonScan {options: options.clone(), predicate: Some(predicate)};
+                        let lp_top = lp_arena.add(lp);
+                        let stack_opt = StackOptimizer{};
+                        let lp_top = stack_opt.optimize_loop(&mut [Box::new(SimplifyExprRule{})], expr_arena, lp_arena, lp_top).unwrap();
+                        let PythonScan {options: _, predicate: Some(predicate)} = lp_arena.take(lp_top) else {unreachable!()};
+
                         match super::super::pyarrow::predicate_to_pa(predicate, expr_arena) {
                             // we we able to create a pyarrow string, mutate the options
                             Some(eval_str) => {
