@@ -2,6 +2,7 @@ use polars_arrow::utils::CustomIterTools;
 use polars_core::export::rayon::prelude::*;
 use polars_core::frame::groupby::GroupsProxy;
 use polars_core::prelude::*;
+use polars_core::series::IsSorted;
 use polars_core::POOL;
 #[cfg(feature = "serde")]
 use serde::{Deserialize, Serialize};
@@ -98,7 +99,7 @@ impl Wrap<&DataFrame> {
         by: Vec<Series>,
         options: &RollingGroupOptions,
     ) -> PolarsResult<(Series, Vec<Series>, GroupsProxy)> {
-        let time = self.0.column(&options.index_column)?;
+        let time = self.0.column(&options.index_column)?.clone();
         let time_type = time.dtype();
 
         if time.null_count() > 0 {
@@ -203,7 +204,7 @@ impl Wrap<&DataFrame> {
 
     fn impl_groupby_dynamic(
         &self,
-        dt: Series,
+        mut dt: Series,
         mut by: Vec<Series>,
         options: &DynamicGroupOptions,
         tu: TimeUnit,
@@ -212,15 +213,13 @@ impl Wrap<&DataFrame> {
         if dt.is_empty() {
             return dt.cast(time_type).map(|s| (s, by, GroupsProxy::default()));
         }
+        // a requirement for the index
+        // so we can set this such that downstream code has this info
+        dt.set_sorted_flag(IsSorted::Ascending);
 
         let w = Window::new(options.every, options.period, options.offset);
         let dt = dt.datetime().unwrap();
         let tz = dt.time_zone();
-        let dt = match tz {
-            #[cfg(feature = "timezones")]
-            Some(_) => dt.replace_time_zone(None)?,
-            _ => dt.clone(),
-        };
 
         let mut lower_bound = None;
         let mut upper_bound = None;
@@ -258,6 +257,7 @@ impl Wrap<&DataFrame> {
                 ts,
                 options.closed_window,
                 tu,
+                tz,
                 include_lower_bound,
                 include_upper_bound,
                 options.start_by,
@@ -289,6 +289,7 @@ impl Wrap<&DataFrame> {
                                     ts,
                                     options.closed_window,
                                     tu,
+                                    tz,
                                     include_lower_bound,
                                     include_upper_bound,
                                     options.start_by,
@@ -318,6 +319,7 @@ impl Wrap<&DataFrame> {
                                     ts,
                                     options.closed_window,
                                     tu,
+                                    tz,
                                     include_lower_bound,
                                     include_upper_bound,
                                     options.start_by,
@@ -352,6 +354,7 @@ impl Wrap<&DataFrame> {
                                     ts,
                                     options.closed_window,
                                     tu,
+                                    tz,
                                     include_lower_bound,
                                     include_upper_bound,
                                     options.start_by,
@@ -373,6 +376,7 @@ impl Wrap<&DataFrame> {
                                     ts,
                                     options.closed_window,
                                     tu,
+                                    tz,
                                     include_lower_bound,
                                     include_upper_bound,
                                     options.start_by,
@@ -389,7 +393,7 @@ impl Wrap<&DataFrame> {
             }
         };
 
-        let dt = unsafe { dt.into_series().agg_first(&groups) };
+        let dt = unsafe { dt.clone().into_series().agg_first(&groups) };
         let mut dt = dt.datetime().unwrap().as_ref().clone();
         for key in by.iter_mut() {
             *key = unsafe { key.agg_first(&groups) };
@@ -405,43 +409,17 @@ impl Wrap<&DataFrame> {
 
         if let (true, Some(lower), Some(higher)) = (options.include_boundaries, lower, upper_bound)
         {
-            match tz {
-                #[cfg(feature = "timezones")]
-                Some(tz) => by.push(
-                    lower
-                        .into_datetime(tu, None)
-                        .replace_time_zone(Some(tz))?
-                        .into_series(),
-                ),
-                _ => by.push(lower.into_datetime(tu, None).into_series()),
-            };
-            let s = match tz {
-                #[cfg(feature = "timezones")]
-                Some(tz) => Int64Chunked::new_vec(UP_NAME, higher)
-                    .into_datetime(tu, None)
-                    .replace_time_zone(Some(tz))?
-                    .into_series(),
-                _ => Int64Chunked::new_vec(UP_NAME, higher)
-                    .into_datetime(tu, None)
-                    .into_series(),
-            };
+            by.push(lower.into_datetime(tu, tz.clone()).into_series());
+            let s = Int64Chunked::new_vec(UP_NAME, higher)
+                .into_datetime(tu, tz.clone())
+                .into_series();
             by.push(s);
         }
 
-        match tz {
-            #[cfg(feature = "timezones")]
-            Some(tz) => dt
-                .into_datetime(tu, None)
-                .replace_time_zone(Some(tz))?
-                .into_series()
-                .cast(time_type)
-                .map(|s| (s, by, groups)),
-            _ => dt
-                .into_datetime(tu, None)
-                .into_series()
-                .cast(time_type)
-                .map(|s| (s, by, groups)),
-        }
+        dt.into_datetime(tu, None)
+            .into_series()
+            .cast(time_type)
+            .map(|s| (s, by, groups))
     }
 
     /// Returns: time_keys, keys, groupsproxy
@@ -454,6 +432,9 @@ impl Wrap<&DataFrame> {
         time_type: &DataType,
     ) -> PolarsResult<(Series, Vec<Series>, GroupsProxy)> {
         let mut dt = dt.rechunk();
+        // a requirement for the index
+        // so we can set this such that downstream code has this info
+        dt.set_sorted_flag(IsSorted::Ascending);
 
         let groups = if by.is_empty() {
             let dt = dt.datetime().unwrap();
