@@ -1,4 +1,4 @@
-#![cfg_attr(docsrs, feature(doc_cfg))]
+#![cfg_attr(docsrs, feature(doc_auto_cfg))]
 pub mod chunkedarray;
 mod date_range;
 mod groupby;
@@ -7,8 +7,10 @@ mod round;
 pub mod series;
 mod truncate;
 mod upsample;
+mod utils;
 mod windows;
 
+use chrono::FixedOffset;
 pub use date_range::*;
 #[cfg(any(feature = "dtype-date", feature = "dtype-datetime"))]
 pub use groupby::dynamic::*;
@@ -19,3 +21,4 @@ pub use windows::calendar::date_range as date_range_vec;
 pub use windows::duration::Duration;
 pub use windows::groupby::ClosedWindow;
 pub use windows::window::Window;
+pub const NO_TIMEZONE: Option<&FixedOffset> = None;
