@@ -20,7 +20,8 @@ impl PolarsRound for DatetimeChunked {
             TimeUnit::Milliseconds => Window::round_ms,
         };
 
-        self.apply(|t| func(&w, t))
+        // TODO remove unwrap once time zone is respected
+        self.apply(|t| func(&w, t, NO_TIMEZONE).unwrap())
             .into_datetime(self.time_unit(), self.time_zone().clone())
     }
 }
@@ -32,7 +33,8 @@ impl PolarsRound for DateChunked {
         let w = Window::new(every, every, offset);
         self.apply(|t| {
             const MSECS_IN_DAY: i64 = MILLISECONDS * SECONDS_IN_DAY;
-            (w.round_ms(MSECS_IN_DAY * t as i64) / MSECS_IN_DAY) as i32
+            // TODO remove unwrap once time zone is respected
+            (w.round_ms(MSECS_IN_DAY * t as i64, NO_TIMEZONE).unwrap() / MSECS_IN_DAY) as i32
         })
         .into_date()
     }
