@@ -21,7 +21,9 @@ fn test_date_range() {
         Duration::parse("1mo"),
         ClosedWindow::Both,
         TimeUnit::Nanoseconds,
-    );
+        NO_TIMEZONE,
+    )
+    .unwrap(); // unwrapping as we pass None as the time zone
     let expected = [
         NaiveDate::from_ymd_opt(2022, 1, 1).unwrap(),
         NaiveDate::from_ymd_opt(2022, 2, 1).unwrap(),
@@ -50,7 +52,9 @@ fn test_feb_date_range() {
         Duration::parse("1mo"),
         ClosedWindow::Both,
         TimeUnit::Nanoseconds,
-    );
+        NO_TIMEZONE,
+    )
+    .unwrap(); // unwrapping as we pass None as the time zone
     let expected = [
         NaiveDate::from_ymd_opt(2022, 2, 1).unwrap(),
         NaiveDate::from_ymd_opt(2022, 3, 1).unwrap(),
@@ -94,6 +98,7 @@ fn test_groups_large_interval() {
         &ts,
         ClosedWindow::Both,
         TimeUnit::Nanoseconds,
+        &None,
         false,
         false,
         Default::default(),
@@ -108,6 +113,7 @@ fn test_groups_large_interval() {
         &ts,
         ClosedWindow::Left,
         TimeUnit::Nanoseconds,
+        &None,
         false,
         false,
         Default::default(),
@@ -119,6 +125,7 @@ fn test_groups_large_interval() {
         &ts,
         ClosedWindow::Right,
         TimeUnit::Nanoseconds,
+        &None,
         false,
         false,
         Default::default(),
@@ -140,7 +147,7 @@ fn test_offset() {
         Duration::parse("-2m"),
     );
 
-    let b = w.get_earliest_bounds_ns(t);
+    let b = w.get_earliest_bounds_ns(t, NO_TIMEZONE).unwrap();
     let start = NaiveDate::from_ymd_opt(2020, 1, 1)
         .unwrap()
         .and_hms_opt(23, 58, 0)
@@ -166,7 +173,9 @@ fn test_boundaries() {
         Duration::parse("30m"),
         ClosedWindow::Both,
         TimeUnit::Nanoseconds,
-    );
+        NO_TIMEZONE,
+    )
+    .unwrap(); // unwrapping as we pass None as the time zone
 
     // window:
     // every 2h
@@ -178,7 +187,7 @@ fn test_boundaries() {
     );
 
     // earliest bound is first datapoint: 2021-12-16 00:00:00
-    let b = w.get_earliest_bounds_ns(ts[0]);
+    let b = w.get_earliest_bounds_ns(ts[0], NO_TIMEZONE).unwrap();
     assert_eq!(b.start, start.timestamp_nanos());
 
     // test closed: "both" (includes both ends of the interval)
@@ -187,6 +196,7 @@ fn test_boundaries() {
         &ts,
         ClosedWindow::Both,
         TimeUnit::Nanoseconds,
+        &None,
         true,
         true,
         Default::default(),
@@ -282,6 +292,7 @@ fn test_boundaries() {
         &ts,
         ClosedWindow::Left,
         TimeUnit::Nanoseconds,
+        &None,
         false,
         false,
         Default::default(),
@@ -296,6 +307,7 @@ fn test_boundaries() {
         &ts,
         ClosedWindow::Right,
         TimeUnit::Nanoseconds,
+        &None,
         false,
         false,
         Default::default(),
@@ -310,6 +322,7 @@ fn test_boundaries() {
         &ts,
         ClosedWindow::None,
         TimeUnit::Nanoseconds,
+        &None,
         false,
         false,
         Default::default(),
@@ -336,7 +349,9 @@ fn test_boundaries_2() {
         Duration::parse("30m"),
         ClosedWindow::Both,
         TimeUnit::Nanoseconds,
-    );
+        NO_TIMEZONE,
+    )
+    .unwrap(); // unwrapping as we pass None as the time zone
 
     print_ns(&ts);
 
@@ -348,7 +363,7 @@ fn test_boundaries_2() {
     let w = Window::new(Duration::parse("2h"), Duration::parse("1h"), offset);
 
     // earliest bound is first datapoint: 2021-12-16 00:00:00 + 30m offset: 2021-12-16 00:30:00
-    let b = w.get_earliest_bounds_ns(ts[0]);
+    let b = w.get_earliest_bounds_ns(ts[0], NO_TIMEZONE).unwrap();
 
     assert_eq!(b.start, start.timestamp_nanos() + offset.duration_ns());
 
@@ -357,6 +372,7 @@ fn test_boundaries_2() {
         &ts,
         ClosedWindow::Left,
         TimeUnit::Nanoseconds,
+        &None,
         true,
         true,
         Default::default(),
@@ -441,7 +457,9 @@ fn test_boundaries_ms() {
         Duration::parse("30m"),
         ClosedWindow::Both,
         TimeUnit::Milliseconds,
-    );
+        NO_TIMEZONE,
+    )
+    .unwrap(); // unwrapping as we pass None as the time zone
 
     // window:
     // every 2h
@@ -453,7 +471,7 @@ fn test_boundaries_ms() {
     );
 
     // earliest bound is first datapoint: 2021-12-16 00:00:00
-    let b = w.get_earliest_bounds_ms(ts[0]);
+    let b = w.get_earliest_bounds_ms(ts[0], NO_TIMEZONE).unwrap();
     assert_eq!(b.start, start.timestamp_millis());
 
     // test closed: "both" (includes both ends of the interval)
@@ -462,6 +480,7 @@ fn test_boundaries_ms() {
         &ts,
         ClosedWindow::Both,
         TimeUnit::Milliseconds,
+        &None,
         true,
         true,
         Default::default(),
@@ -557,6 +576,7 @@ fn test_boundaries_ms() {
         &ts,
         ClosedWindow::Left,
         TimeUnit::Milliseconds,
+        &None,
         false,
         false,
         Default::default(),
@@ -571,6 +591,7 @@ fn test_boundaries_ms() {
         &ts,
         ClosedWindow::Right,
         TimeUnit::Milliseconds,
+        &None,
         false,
         false,
         Default::default(),
@@ -585,6 +606,7 @@ fn test_boundaries_ms() {
         &ts,
         ClosedWindow::None,
         TimeUnit::Milliseconds,
+        &None,
         false,
         false,
         Default::default(),
@@ -611,7 +633,9 @@ fn test_rolling_lookback() {
         Duration::parse("30m"),
         ClosedWindow::Both,
         TimeUnit::Milliseconds,
-    );
+        NO_TIMEZONE,
+    )
+    .unwrap(); // unwrapping as we pass None as the time zone
 
     // full lookbehind
     let groups = groupby_values(
@@ -726,6 +750,7 @@ fn test_end_membership() {
         &time,
         ClosedWindow::Left,
         TimeUnit::Milliseconds,
+        &None,
         false,
         false,
         Default::default(),
@@ -749,6 +774,7 @@ fn test_groupby_windows_membership_2791() {
         &dates,
         ClosedWindow::Left,
         TimeUnit::Milliseconds,
+        &None,
         false,
         false,
         Default::default(),
@@ -771,6 +797,7 @@ fn test_groupby_windows_duplicates_2931() {
         &dates,
         ClosedWindow::Left,
         TimeUnit::Milliseconds,
+        &None,
         false,
         false,
         Default::default(),
@@ -800,6 +827,7 @@ fn test_groupby_windows_offsets_3776() {
         &ts,
         ClosedWindow::Right,
         TimeUnit::Nanoseconds,
+        &None,
         false,
         false,
         Default::default(),
