@@ -1,19 +1,7 @@
 import os
-import warnings
-
-try:
-    from polars.polars import version
-except ImportError:
-
-    def version() -> str:
-        return ""
-
-    # this is only useful for documentation
-    warnings.warn("polars binary missing!")
 
 from polars import api
-from polars.build_info import build_info
-from polars.cfg import Config
+from polars.config import Config
 from polars.convert import (
     from_arrow,
     from_dataframe,
@@ -23,13 +11,26 @@ from polars.convert import (
     from_pandas,
     from_records,
 )
+
+# TODO remove need for wrap_df
+from polars.dataframe import (
+    DataFrame,
+    wrap_df,  # noqa: F401
+)
 from polars.datatypes import (
+    DATETIME_DTYPES,
+    DURATION_DTYPES,
+    FLOAT_DTYPES,
+    INTEGER_DTYPES,
+    NUMERIC_DTYPES,
+    TEMPORAL_DTYPES,
     Binary,
     Boolean,
     Categorical,
     DataType,
     Date,
     Datetime,
+    Decimal,
     Duration,
     Field,
     Float32,
@@ -41,7 +42,6 @@ from polars.datatypes import (
     List,
     Null,
     Object,
-    PolarsDataType,
     Struct,
     Time,
     UInt8,
@@ -50,7 +50,6 @@ from polars.datatypes import (
     UInt64,
     Unknown,
     Utf8,
-    get_idx_type,
 )
 from polars.exceptions import (
     ArrowError,
@@ -65,15 +64,8 @@ from polars.exceptions import (
     ShapeError,
     StructFieldNotFoundError,
 )
-from polars.internals import BatchedCsvReader
-
-# TODO remove need for wrap_df
-from polars.internals.dataframe import (
-    DataFrame,
-    wrap_df,  # noqa: F401
-)
-from polars.internals.expr.expr import Expr
-from polars.internals.functions import (
+from polars.expr.expr import Expr
+from polars.functions.eager import (
     align_frames,
     concat,
     cut,
@@ -82,10 +74,7 @@ from polars.internals.functions import (
     ones,
     zeros,
 )
-from polars.internals.io import read_ipc_schema, read_parquet_schema
-from polars.internals.lazy_functions import _date as date
-from polars.internals.lazy_functions import _datetime as datetime
-from polars.internals.lazy_functions import (
+from polars.functions.lazy import (
     all,
     any,
     apply,
@@ -99,6 +88,7 @@ from polars.internals.lazy_functions import (
     collect_all,
     concat_list,
     concat_str,
+    corr,
     count,
     cov,
     cumfold,
@@ -133,18 +123,16 @@ from polars.internals.lazy_functions import (
     tail,
     var,
 )
-from polars.internals.lazy_functions import to_list as list
-from polars.internals.lazyframe import LazyFrame
-
-# TODO: remove need for wrap_s
-from polars.internals.series import wrap_s  # noqa: F401
-from polars.internals.series.series import Series
-from polars.internals.sql import SQLContext
-from polars.internals.whenthen import when
+from polars.functions.lazy import date_ as date
+from polars.functions.lazy import datetime_ as datetime
+from polars.functions.lazy import list_ as list
+from polars.functions.whenthen import when
+from polars.internals.io import read_ipc_schema, read_parquet_schema
 from polars.io import (
     read_avro,
     read_csv,
     read_csv_batched,
+    read_database,
     read_delta,
     read_excel,
     read_ipc,
@@ -158,10 +146,27 @@ from polars.io import (
     scan_ipc,
     scan_ndjson,
     scan_parquet,
+    scan_pyarrow_dataset,
 )
-from polars.show_versions import show_versions
+from polars.lazyframe import LazyFrame
+
+# TODO: remove need for wrap_s
+from polars.series import wrap_s  # noqa: F401
+from polars.series.series import Series
+from polars.sql import SQLContext
 from polars.string_cache import StringCache, toggle_string_cache, using_string_cache
-from polars.utils import threadpool_size
+from polars.type_aliases import PolarsDataType
+from polars.utils import (
+    build_info,
+    get_idx_type,
+    get_index_type,
+    show_versions,
+    threadpool_size,
+)
+from polars.utils.polars_version import get_polars_version as _get_polars_version
+
+__version__: str = _get_polars_version()
+del _get_polars_version
 
 __all__ = [
     "api",
@@ -179,7 +184,6 @@ __all__ = [
     "ShapeError",
     "StructFieldNotFoundError",
     # core classes
-    "BatchedCsvReader",
     "DataFrame",
     "Expr",
     "LazyFrame",
@@ -191,6 +195,7 @@ __all__ = [
     "DataType",
     "Date",
     "Datetime",
+    "Decimal",
     "Duration",
     "Field",
     "Float32",
@@ -202,7 +207,6 @@ __all__ = [
     "List",
     "Null",
     "Object",
-    "PolarsDataType",
     "Struct",
     "Time",
     "UInt16",
@@ -211,11 +215,20 @@ __all__ = [
     "UInt8",
     "Unknown",
     "Utf8",
-    "get_idx_type",
+    # polars.datatypes: dtype groups
+    "DATETIME_DTYPES",
+    "DURATION_DTYPES",
+    "FLOAT_DTYPES",
+    "INTEGER_DTYPES",
+    "NUMERIC_DTYPES",
+    "TEMPORAL_DTYPES",
+    # polars.type_aliases
+    "PolarsDataType",
     # polars.io
     "read_avro",
     "read_csv",
     "read_csv_batched",
+    "read_database",
     "read_delta",
     "read_excel",
     "read_ipc",
@@ -231,6 +244,7 @@ __all__ = [
     "scan_ipc",
     "scan_ndjson",
     "scan_parquet",
+    "scan_pyarrow_dataset",
     # polars.stringcache
     "StringCache",
     "toggle_string_cache",
@@ -263,13 +277,14 @@ __all__ = [
     "collect_all",
     "concat_list",
     "concat_str",
+    "corr",
     "count",
     "cov",
     "cumfold",
     "cumreduce",
     "cumsum",
-    "date",  # name _date, see import above
-    "datetime",  # named _datetime, see import above
+    "date",  # named date_, see import above
+    "datetime",  # named datetime_, see import above
     "duration",
     "exclude",
     "first",
@@ -279,7 +294,7 @@ __all__ = [
     "groups",
     "head",
     "last",
-    "list",  # named to_list, see import above
+    "list",  # named list_, see import above
     "lit",
     "map",
     "max",
@@ -306,14 +321,14 @@ __all__ = [
     "from_numpy",
     "from_pandas",
     "from_records",
-    # testing
-    "threadpool_size",
-    # version
+    # sql
     "SQLContext",
+    # utils
     "build_info",
+    "get_idx_type",
+    "get_index_type",
     "show_versions",
+    "threadpool_size",
 ]
 
-__version__ = version()
-
 os.environ["POLARS_ALLOW_EXTENSION"] = "true"
