@@ -689,11 +689,11 @@ impl PyExpr {
     }
 
     #[cfg(feature = "lazy_regex")]
-    pub fn str_replace(&self, pat: PyExpr, val: PyExpr, literal: bool) -> PyExpr {
+    pub fn str_replace_n(&self, pat: PyExpr, val: PyExpr, literal: bool, n: i64) -> PyExpr {
         self.inner
             .clone()
             .str()
-            .replace(pat.inner, val.inner, literal)
+            .replace_n(pat.inner, val.inner, literal, n)
             .into()
     }
 
@@ -1993,6 +1993,8 @@ pub fn lit(value: &PyAny, allow_object: bool) -> PyResult<PyExpr> {
         Ok(dsl::lit(series.series).into())
     } else if value.is_none() {
         Ok(dsl::lit(Null {}).into())
+    } else if let Ok(value) = value.downcast::<PyBytes>() {
+        Ok(dsl::lit(value.as_bytes()).into())
     } else if allow_object {
         let s = Python::with_gil(|py| {
             PySeries::new_object("", vec![ObjectValue::from(value.into_py(py))], false).series
