@@ -6,6 +6,7 @@ from typing import Iterator
 import pytest
 
 import polars as pl
+from polars.testing import assert_frame_equal
 
 
 @pytest.fixture(autouse=True)
@@ -81,9 +82,9 @@ def test_set_tbl_cols() -> None:
     df = pl.DataFrame({"a": [1, 2, 3], "b": [4, 5, 6], "c": [7, 8, 9]})
 
     pl.Config.set_tbl_cols(1)
-    assert str(df).split("\n")[2] == "│ a   ┆ ... │"
+    assert str(df).split("\n")[2] == "│ a   ┆ … │"
     pl.Config.set_tbl_cols(2)
-    assert str(df).split("\n")[2] == "│ a   ┆ ... ┆ c   │"
+    assert str(df).split("\n")[2] == "│ a   ┆ … ┆ c   │"
     pl.Config.set_tbl_cols(3)
     assert str(df).split("\n")[2] == "│ a   ┆ b   ┆ c   │"
 
@@ -91,15 +92,14 @@ def test_set_tbl_cols() -> None:
         {"a": [1, 2, 3], "b": [4, 5, 6], "c": [7, 8, 9], "d": [10, 11, 12]}
     )
     pl.Config.set_tbl_cols(2)
-    assert str(df).split("\n")[2] == "│ a   ┆ ... ┆ d   │"
+    assert str(df).split("\n")[2] == "│ a   ┆ … ┆ d   │"
     pl.Config.set_tbl_cols(3)
-    assert str(df).split("\n")[2] == "│ a   ┆ b   ┆ ... ┆ d   │"
+    assert str(df).split("\n")[2] == "│ a   ┆ b   ┆ … ┆ d   │"
     pl.Config.set_tbl_cols(-1)
     assert str(df).split("\n")[2] == "│ a   ┆ b   ┆ c   ┆ d   │"
 
 
 def test_set_tbl_rows() -> None:
-
     df = pl.DataFrame({"a": [1, 2, 3, 4], "b": [5, 6, 7, 8], "c": [9, 10, 11, 12]})
     ser = pl.Series("ser", [1, 2, 3, 4, 5])
 
@@ -111,10 +111,10 @@ def test_set_tbl_rows() -> None:
         "│ --- ┆ --- ┆ --- │\n"
         "│ i64 ┆ i64 ┆ i64 │\n"
         "╞═════╪═════╪═════╡\n"
-        "│ ... ┆ ... ┆ ... │\n"
+        "│ …   ┆ …   ┆ …   │\n"
         "└─────┴─────┴─────┘"
     )
-    assert str(ser) == "shape: (5,)\n" "Series: 'ser' [i64]\n" "[\n" "\t...\n" "]"
+    assert str(ser) == "shape: (5,)\n" "Series: 'ser' [i64]\n" "[\n" "\t…\n" "]"
 
     pl.Config.set_tbl_rows(1)
     assert (
@@ -125,12 +125,10 @@ def test_set_tbl_rows() -> None:
         "│ i64 ┆ i64 ┆ i64 │\n"
         "╞═════╪═════╪═════╡\n"
         "│ 1   ┆ 5   ┆ 9   │\n"
-        "│ ... ┆ ... ┆ ... │\n"
+        "│ …   ┆ …   ┆ …   │\n"
         "└─────┴─────┴─────┘"
     )
-    assert (
-        str(ser) == "shape: (5,)\n" "Series: 'ser' [i64]\n" "[\n" "\t1\n" "\t...\n" "]"
-    )
+    assert str(ser) == "shape: (5,)\n" "Series: 'ser' [i64]\n" "[\n" "\t1\n" "\t…\n" "]"
 
     pl.Config.set_tbl_rows(2)
     assert (
@@ -141,7 +139,7 @@ def test_set_tbl_rows() -> None:
         "│ i64 ┆ i64 ┆ i64 │\n"
         "╞═════╪═════╪═════╡\n"
         "│ 1   ┆ 5   ┆ 9   │\n"
-        "│ ... ┆ ... ┆ ... │\n"
+        "│ …   ┆ …   ┆ …   │\n"
         "│ 4   ┆ 8   ┆ 12  │\n"
         "└─────┴─────┴─────┘"
     )
@@ -150,7 +148,7 @@ def test_set_tbl_rows() -> None:
         "Series: 'ser' [i64]\n"
         "[\n"
         "\t1\n"
-        "\t...\n"
+        "\t…\n"
         "\t5\n"
         "]"
     )
@@ -164,7 +162,7 @@ def test_set_tbl_rows() -> None:
         "│ i64 ┆ i64 ┆ i64 │\n"
         "╞═════╪═════╪═════╡\n"
         "│ 1   ┆ 5   ┆ 9   │\n"
-        "│ ... ┆ ... ┆ ... │\n"
+        "│ …   ┆ …   ┆ …   │\n"
         "│ 3   ┆ 7   ┆ 11  │\n"
         "│ 4   ┆ 8   ┆ 12  │\n"
         "└─────┴─────┴─────┘"
@@ -174,7 +172,7 @@ def test_set_tbl_rows() -> None:
         "Series: 'ser' [i64]\n"
         "[\n"
         "\t1\n"
-        "\t...\n"
+        "\t…\n"
         "\t4\n"
         "\t5\n"
         "]"
@@ -200,7 +198,7 @@ def test_set_tbl_rows() -> None:
         "[\n"
         "\t1\n"
         "\t2\n"
-        "\t...\n"
+        "\t…\n"
         "\t4\n"
         "\t5\n"
         "]"
@@ -223,7 +221,7 @@ def test_set_tbl_rows() -> None:
         "│ i64 ┆ i64 ┆ i64 │\n"
         "╞═════╪═════╪═════╡\n"
         "│ 1   ┆ 6   ┆ 11  │\n"
-        "│ ... ┆ ... ┆ ... │\n"
+        "│ …   ┆ …   ┆ …   │\n"
         "│ 4   ┆ 9   ┆ 14  │\n"
         "│ 5   ┆ 10  ┆ 15  │\n"
         "└─────┴─────┴─────┘"
@@ -327,7 +325,7 @@ def test_set_tbl_width_chars() -> None:
             "this is 10": [4, 5, 6],
         }
     )
-    assert max(len(line) for line in str(df).split("\n")) == 72
+    assert max(len(line) for line in str(df).split("\n")) == 70
 
     pl.Config.set_tbl_width_chars(60)
     assert max(len(line) for line in str(df).split("\n")) == 60
@@ -407,37 +405,43 @@ def test_string_cache() -> None:
     df1b = df1.with_columns(pl.col("a").cast(pl.Categorical))
     df2b = df2.with_columns(pl.col("a").cast(pl.Categorical))
     out = df1b.join(df2b, on="a", how="inner")
-    assert out.frame_equal(pl.DataFrame({"a": ["foo"], "b": [1], "c": [3]}))
+
+    expected = pl.DataFrame(
+        {"a": ["foo"], "b": [1], "c": [3]}, schema_overrides={"a": pl.Categorical}
+    )
+    assert_frame_equal(out, expected)
 
 
 def test_config_load_save() -> None:
-    # set some config options
-    pl.Config.with_columns_kwargs = True
+    # set some config options...
+    pl.Config.set_tbl_cols(12)
     pl.Config.set_verbose(True)
-    assert os.environ["POLARS_VERBOSE"] == "1"
+    assert os.environ.get("POLARS_VERBOSE") == "1"
 
     cfg = pl.Config.save()
     assert isinstance(cfg, str)
     assert "POLARS_VERBOSE" in pl.Config.state(if_set=True)
 
-    # unset the saved options
-    pl.Config.with_columns_kwargs = False
+    # ...modify the same options...
+    pl.Config.set_tbl_cols(10)
     pl.Config.set_verbose(False)
-    assert os.environ["POLARS_VERBOSE"] == "0"
+    assert os.environ.get("POLARS_VERBOSE") == "0"
 
-    # now load back from config...
+    # ...load back from config...
     pl.Config.load(cfg)
 
-    # ...and confirm the saved options were set
-    assert os.environ["POLARS_VERBOSE"] == "1"
-    assert pl.Config.with_columns_kwargs is True
+    # ...and confirm the saved options were set.
+    assert os.environ.get("POLARS_FMT_MAX_COLS") == "12"
+    assert os.environ.get("POLARS_VERBOSE") == "1"
 
-    # restore explicitly-set config options (unsets from env)
+    # restore all default options (unsets from env)
     pl.Config.restore_defaults()
-    assert "POLARS_VERBOSE" not in pl.Config.state(if_set=True)
-    assert "POLARS_VERBOSE" in pl.Config.state()
+    for e in ("POLARS_FMT_MAX_COLS", "POLARS_VERBOSE"):
+        assert e not in pl.Config.state(if_set=True)
+        assert e in pl.Config.state()
+
+    assert os.environ.get("POLARS_FMT_MAX_COLS") is None
     assert os.environ.get("POLARS_VERBOSE") is None
-    assert pl.Config.with_columns_kwargs is False
 
 
 def test_config_scope() -> None:
